summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorOssama Othman <ossama-othman@users.noreply.github.com>2001-12-09 01:08:32 +0000
committerOssama Othman <ossama-othman@users.noreply.github.com>2001-12-09 01:08:32 +0000
commita9389a6b96b77788162a267a3a3b1977a13f674f (patch)
tree59e1e80c8160ea2978cc4cb5dd8ee314d9b0ca56
parent63165b00e2d667e39e15cf084128d94a563d484e (diff)
downloadATCD-a9389a6b96b77788162a267a3a3b1977a13f674f.tar.gz
ChangeLogTag:Sat Dec 8 17:07:01 2001 Ossama Othman <ossama@uci.edu>
-rw-r--r--ChangeLog7
-rw-r--r--ChangeLogs/ChangeLog-02a7
-rw-r--r--ChangeLogs/ChangeLog-03a7
-rwxr-xr-xbin/fuzz.pl8
4 files changed, 25 insertions, 4 deletions
diff --git a/ChangeLog b/ChangeLog
index c6a729c4f21..41e93e1e8cc 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,10 @@
+Sat Dec 8 17:07:01 2001 Ossama Othman <ossama@uci.edu>
+
+ * bin/fuzz.pl (check_for_missing_rir_env):
+
+ Check for TAO_ENV_ARG_PARAMETER instead of ACE_TRY_ENV. TAO now
+ uses the former instead of the latter.
+
Sat Dec 8 09:39:48 2001 Douglas C. Schmidt <schmidt@macarena.cs.wustl.edu>
* ace/OS.cpp (string_to_argv): Improved the support for quoted strings.
diff --git a/ChangeLogs/ChangeLog-02a b/ChangeLogs/ChangeLog-02a
index c6a729c4f21..41e93e1e8cc 100644
--- a/ChangeLogs/ChangeLog-02a
+++ b/ChangeLogs/ChangeLog-02a
@@ -1,3 +1,10 @@
+Sat Dec 8 17:07:01 2001 Ossama Othman <ossama@uci.edu>
+
+ * bin/fuzz.pl (check_for_missing_rir_env):
+
+ Check for TAO_ENV_ARG_PARAMETER instead of ACE_TRY_ENV. TAO now
+ uses the former instead of the latter.
+
Sat Dec 8 09:39:48 2001 Douglas C. Schmidt <schmidt@macarena.cs.wustl.edu>
* ace/OS.cpp (string_to_argv): Improved the support for quoted strings.
diff --git a/ChangeLogs/ChangeLog-03a b/ChangeLogs/ChangeLog-03a
index c6a729c4f21..41e93e1e8cc 100644
--- a/ChangeLogs/ChangeLog-03a
+++ b/ChangeLogs/ChangeLog-03a
@@ -1,3 +1,10 @@
+Sat Dec 8 17:07:01 2001 Ossama Othman <ossama@uci.edu>
+
+ * bin/fuzz.pl (check_for_missing_rir_env):
+
+ Check for TAO_ENV_ARG_PARAMETER instead of ACE_TRY_ENV. TAO now
+ uses the former instead of the latter.
+
Sat Dec 8 09:39:48 2001 Douglas C. Schmidt <schmidt@macarena.cs.wustl.edu>
* ace/OS.cpp (string_to_argv): Improved the support for quoted strings.
diff --git a/bin/fuzz.pl b/bin/fuzz.pl
index 5152d5a93cf..a3d6b1371b8 100755
--- a/bin/fuzz.pl
+++ b/bin/fuzz.pl
@@ -20,7 +20,7 @@ use Getopt::Std;
# - Guards in .h files
# - no global functions
# - other commit_check checks, tabs, trailing spaces.
# - _narrow() should always have ACE_TRY_ENV
# - Using ACE_TRY_NEW_ENV (Nanbor suggests using ACE_DECLARE_NEW_CORBA_ENV)
#
# And others in ACE_Guidelines and Design Rules
@@ -631,7 +631,7 @@ sub check_for_bad_ace_trace()
# This test checks missing ACE_TRY_ENV when using
# resolve_initial_references
sub check_for_missing_rir_env ()
{
@@ -666,14 +666,14 @@ sub check_for_missing_rir_env ()
$in_rir = 1;
}
- if (m/ACE_TRY_ENV/) {
+ if (m/TAO_ENV_ARG_PARAMETER/) {
$found_env = 1;
}
if ($in_rir == 1 && m/\;\s*$/) {
$in_rir = 0;
if ($found_env != 1) {
- print_error ("Missing ACE_TRY_ENV in"
+ print_error ("Missing TAO_ENV_ARG_PARAMETER in"
. " resolve_initial_references"
. " in $file ($line)");
}
@@ -20,7 +20,7 @@ use Getopt::Std;
# - no global functions
# - other commit_check checks, tabs, trailing spaces.
-# - _narrow() should always have ACE_TRY_ENV
+# - _narrow() should always have TAO_ENV_ARG_PARAMETER
# - Using ACE_TRY_NEW_ENV (Nanbor suggests using ACE_DECLARE_NEW_CORBA_ENV)
#
@@ -631,7 +631,7 @@ sub check_for_bad_ace_trace()
# And others in ACE_Guidelines and Design Rules
-# This test checks missing ACE_TRY_ENV when using
+# This test checks missing TAO_ENV_ARG_PARAMETER when using
# resolve_initial_references
sub check_for_missing_rir_env ()